@@ -76,7 +76,7 @@ tablet_force_button_presses(struct tablet_dispatch *tablet)
 	}
 }
 
-static int
+static bool
 tablet_device_has_axis(struct tablet_dispatch *tablet,
 		       enum libinput_tablet_tool_axis axis)
 {
@@ -226,8 +226,9 @@ tablet_update_tool(struct tablet_dispatch *tablet,
 		tablet_set_status(tablet, TABLET_TOOL_ENTERING_PROXIMITY);
 		tablet_unset_status(tablet, TABLET_TOOL_OUT_OF_PROXIMITY);
 	}
-	else if (!tablet_has_status(tablet, TABLET_TOOL_OUT_OF_PROXIMITY))
+	else if (!tablet_has_status(tablet, TABLET_TOOL_OUT_OF_PROXIMITY)) {
 		tablet_set_status(tablet, TABLET_TOOL_LEAVING_PROXIMITY);
+	}
 }
 
 static inline double
@@ -334,7 +335,7 @@ normalize_wheel(struct tablet_dispatch *tablet,
 {
 	struct evdev_device *device = tablet->device;
 
-	return value * device->scroll.wheel_click_angle;
+	return value * device->scroll.wheel_click_angle.x;
 }
 
 static inline void
@@ -1432,6 +1433,39 @@ tablet_flush(struct tablet_dispatch *tablet,
 	}
 }
 
+static inline void
+tablet_set_touch_device_enabled(struct evdev_device *touch_device,
+				bool enable)
+{
+	struct evdev_dispatch *dispatch;
+
+	if (touch_device == NULL)
+		return;
+
+	dispatch = touch_device->dispatch;
+	if (dispatch->interface->toggle_touch)
+		dispatch->interface->toggle_touch(dispatch,
+						  touch_device,
+						  enable);
+}
+
+static inline void
+tablet_toggle_touch_device(struct tablet_dispatch *tablet,
+			   struct evdev_device *tablet_device)
+{
+	bool enable_events;
+
+	enable_events = tablet_has_status(tablet,
+					  TABLET_TOOL_OUT_OF_RANGE) ||
+			tablet_has_status(tablet, TABLET_NONE) ||
+			tablet_has_status(tablet,
+					  TABLET_TOOL_LEAVING_PROXIMITY) ||
+			tablet_has_status(tablet,
+					  TABLET_TOOL_OUT_OF_PROXIMITY);
+
+	tablet_set_touch_device_enabled(tablet->touch_device, enable_events);
+}
+
 static inline void
 tablet_reset_state(struct tablet_dispatch *tablet)
 {
@@ -1465,6 +1499,7 @@ tablet_process(struct evdev_dispatch *dispatch,
 		break;
 	case EV_SYN:
 		tablet_flush(tablet, device, time);
+		tablet_toggle_touch_device(tablet, device);
 		tablet_reset_state(tablet);
 		break;
 	default:
@@ -1476,6 +1511,16 @@ tablet_process(struct evdev_dispatch *dispatch,
 	}
 }
 
+static void
+tablet_suspend(struct evdev_dispatch *dispatch,
+	       struct evdev_device *device)
+{
+	struct tablet_dispatch *tablet =
+		(struct tablet_dispatch *)dispatch;
+
+	tablet_set_touch_device_enabled(tablet->touch_device, true);
+}
+
 static void
 tablet_destroy(struct evdev_dispatch *dispatch)
 {
@@ -1490,6 +1535,35 @@ tablet_destroy(struct evdev_dispatch *dispatch)
 	free(tablet);
 }
 
+static void
+tablet_device_added(struct evdev_device *device,
+		    struct evdev_device *added_device)
+{
+	struct tablet_dispatch *tablet =
+		(struct tablet_dispatch*)device->dispatch;
+
+	if (libinput_device_get_device_group(&device->base) !=
+	    libinput_device_get_device_group(&added_device->base))
+		return;
+
+	/* Touch screens or external touchpads only */
+	if (evdev_device_has_capability(added_device, LIBINPUT_DEVICE_CAP_TOUCH) ||
+	    (evdev_device_has_capability(added_device, LIBINPUT_DEVICE_CAP_POINTER) &&
+	     (added_device->tags & EVDEV_TAG_EXTERNAL_TOUCHPAD)))
+	    tablet->touch_device = added_device;
+}
+
+static void
+tablet_device_removed(struct evdev_device *device,
+		      struct evdev_device *removed_device)
+{
+	struct tablet_dispatch *tablet =
+		(struct tablet_dispatch*)device->dispatch;
+
+	if (tablet->touch_device == removed_device)
+		tablet->touch_device = NULL;
+}
+
 static void
 tablet_check_initial_proximity(struct evdev_device *device,
 			       struct evdev_dispatch *dispatch)
@@ -1531,14 +1605,15 @@ tablet_check_initial_proximity(struct evdev_device *device,
 
 static struct evdev_dispatch_interface tablet_interface = {
 	tablet_process,
-	NULL, /* suspend */
+	tablet_suspend,
 	NULL, /* remove */
 	tablet_destroy,
-	NULL, /* device_added */
-	NULL, /* device_removed */
+	tablet_device_added,
+	tablet_device_removed,
 	NULL, /* device_suspended */
 	NULL, /* device_resumed */
 	tablet_check_initial_proximity,
+	NULL, /* toggle_touch */
 };
 
 static void
@@ -1546,7 +1621,7 @@ tablet_init_calibration(struct tablet_dispatch *tablet,
 			struct evdev_device *device)
 {
 	if (libevdev_has_property(device->evdev, INPUT_PROP_DIRECT))
-		evdev_init_calibration(device, &tablet->base);
+		evdev_init_calibration(device, &tablet->calibration);
 }
 
 static void
@@ -1603,7 +1678,6 @@ tablet_init_accel(struct tablet_dispatch *tablet, struct evdev_device *device)
 {
 	const struct input_absinfo *x, *y;
 	struct motion_filter *filter;
-	int rc;
 
 	x = device->abs.absinfo_x;
 	y = device->abs.absinfo_y;
@@ -1613,9 +1687,7 @@ tablet_init_accel(struct tablet_dispatch *tablet, struct evdev_device *device)
 	if (!filter)
 		return -1;
 
-	rc = evdev_device_init_pointer_acceleration(device, filter);
-	if (rc != 0)
-		return rc;
+	evdev_device_init_pointer_acceleration(device, filter);
 
 	/* we override the profile hooks for accel configuration with hooks
 	 * that don't allow selection of profiles */
